@@ -8,6 +8,7 @@ __all__ = [
     "default_float",
     "default_int",
     "default_jitter",
+    "default_likelihood_positive_minimum",
     "default_positive_bijector",
     "default_positive_minimum",
     "default_summary_fmt",
@@ -16,6 +17,7 @@ __all__ = [
     "set_default_float",
     "set_default_int",
     "set_default_jitter",
+    "set_default_likelihood_positive_minimum",
     "set_default_positive_bijector",
     "set_default_positive_minimum",
     "set_default_summary_fmt",
