@@ -15,12 +15,12 @@
 from typing import Optional
 
 import tensorflow as tf
+from check_shapes import check_shapes, inherit_check_shapes
 
 import gpflow
 
 from .. import posteriors
 from ..base import InputData, MeanAndVariance, RegressionData, TensorData
-from ..experimental.check_shapes import check_shapes, inherit_check_shapes
 from ..kernels import Kernel
 from ..likelihoods import Gaussian
 from ..logdensities import multivariate_normal
@@ -52,6 +52,8 @@ class GPR_deprecated(GPModel, InternalDataTrainingLossMixin):
     .. math::
        \log p(Y \,|\, \sigma_n, \theta) =
             \mathcal N(Y \,|\, 0, \mathbf{K} + \sigma_n^2 \mathbf{I})
+
+    For a use example see :doc:`../../../../notebooks/getting_started/basic_usage`.
     """
 
     @check_shapes(
@@ -190,4 +192,5 @@ class GPR_with_posterior(GPR_deprecated):
 
 class GPR(GPR_with_posterior):
     # subclassed to ensure __class__ == "GPR"
-    pass
+
+    __doc__ = GPR_deprecated.__doc__  # Use documentation from GPR_deprecated.
