@@ -16,6 +16,8 @@ This test suite will check if the conditionals broadcast correctly
 when the input tensors have leading dimensions.
 """
 
+from typing import cast
+
 import numpy as np
 import pytest
 import tensorflow as tf
@@ -24,7 +26,7 @@ from numpy.testing import assert_allclose
 import gpflow
 import gpflow.inducing_variables.multioutput as mf
 import gpflow.kernels.multioutput as mk
-from gpflow.base import SamplesMeanAndVariance
+from gpflow.base import AnyNDArray, SamplesMeanAndVariance
 from gpflow.conditionals import sample_conditional
 from gpflow.conditionals.util import mix_latent_gp
 
@@ -63,7 +65,7 @@ def test_conditional_broadcasting(full_cov: bool, white: bool, conditional_type:
     and conditional should broadcast over the [...].
     """
     q_mu = np.random.randn(Data.M, Data.Dy)
-    q_sqrt = np.tril(np.random.randn(Data.Dy, Data.M, Data.M), -1)
+    q_sqrt: AnyNDArray = np.tril(np.random.randn(Data.Dy, Data.M, Data.M), -1)
 
     if conditional_type == "Z":
         inducing_variable = Data.Z
@@ -91,20 +93,23 @@ def test_conditional_broadcasting(full_cov: bool, white: bool, conditional_type:
     num_samples = 5
 
     def sample_conditional_fn(X: tf.Tensor) -> SamplesMeanAndVariance:
-        return sample_conditional(
-            X,
-            inducing_variable,
-            kernel,
-            tf.convert_to_tensor(q_mu),
-            q_sqrt=tf.convert_to_tensor(q_sqrt),
-            white=white,
-            full_cov=full_cov,
-            num_samples=num_samples,
+        return cast(
+            SamplesMeanAndVariance,
+            sample_conditional(
+                X,
+                inducing_variable,
+                kernel,
+                tf.convert_to_tensor(q_mu),
+                q_sqrt=tf.convert_to_tensor(q_sqrt),
+                white=white,
+                full_cov=full_cov,
+                num_samples=num_samples,
+            ),
         )
 
-    samples = np.array([sample_conditional_fn(X)[0] for X in Data.SX])
-    means = np.array([sample_conditional_fn(X)[1] for X in Data.SX])
-    variables = np.array([sample_conditional_fn(X)[2] for X in Data.SX])
+    samples: AnyNDArray = np.array([sample_conditional_fn(X)[0] for X in Data.SX])
+    means: AnyNDArray = np.array([sample_conditional_fn(X)[1] for X in Data.SX])
+    variables: AnyNDArray = np.array([sample_conditional_fn(X)[2] for X in Data.SX])
 
     samples_S12, means_S12, vars_S12 = sample_conditional(
         Data.SX,
@@ -154,19 +159,19 @@ def test_broadcasting_mix_latent_gps(full_cov: bool, full_output_cov: bool) -> N
     W = np.random.randn(P, L)  # mixing matrix
     g_mu = np.random.randn(S, N, L)  # mean of the L latent GPs
 
-    g_sqrt_diag = np.tril(np.random.randn(S * L, N, N), -1)  # [L*S, N, N]
+    g_sqrt_diag: AnyNDArray = np.tril(np.random.randn(S * L, N, N), -1)  # [L*S, N, N]
     g_sqrt_diag = np.reshape(g_sqrt_diag, [L, S, N, N])
-    g_var_diag = g_sqrt_diag @ np.transpose(g_sqrt_diag, [0, 1, 3, 2])  # [L, S, N, N]
+    g_var_diag: AnyNDArray = g_sqrt_diag @ np.transpose(g_sqrt_diag, [0, 1, 3, 2])  # [L, S, N, N]
     g_var = np.zeros([S, N, L, N, L])
     for l in range(L):
         g_var[:, :, l, :, l] = g_var_diag[l, :, :, :]  # replace diagonal elements by g_var_diag
 
     # reference numpy implementation for mean
-    f_mu_ref = g_mu @ W.T  # [S, N, P]
+    f_mu_ref: AnyNDArray = g_mu @ W.T  # [S, N, P]
 
     # reference numpy implementation for variance
     g_var_tmp = np.transpose(g_var, [0, 1, 3, 2, 4])  # [S, N, N, L, L]
-    f_var_ref = W @ g_var_tmp @ W.T  # [S, N, N, P, P]
+    f_var_ref: AnyNDArray = W @ g_var_tmp @ W.T  # [S, N, N, P, P]
     f_var_ref = np.transpose(f_var_ref, [0, 1, 3, 2, 4])  # [S, N, P, N, P]
 
     if not full_cov:
