@@ -25,6 +25,7 @@ import gpflow
 import gpflow.ci_utils
 from gpflow import kernels
 from gpflow.base import AnyNDArray, TensorType
+from gpflow.kernels.categorical import Categorical
 
 
 def create_kernels() -> Sequence[kernels.Kernel]:
@@ -61,6 +62,11 @@ def create_kernels() -> Sequence[kernels.Kernel]:
         kernels.SharedIndependent(kernels.Matern32(), output_dim=5),
         kernels.SeparateIndependent([kernels.Matern32() for _ in range(5)]),
         kernels.LinearCoregionalization([kernels.Matern32() for _ in range(3)], np.ones((5, 3))),
+        Categorical(
+            non_categorical_kernel=kernels.RBF(lengthscales=0.1),
+            categorical_kernel=kernels.RBF(lengthscales=0.1),
+            num_labels=3,
+        ),
     ]
     return result
 
