@@ -49,6 +49,7 @@ from gpflow.kernels import (
     Stationary,
     White,
 )
+from gpflow.kernels.categorical import _concat_inputs_with_latents
 from tests.gpflow.kernels.reference import ref_arccosine_kernel, ref_periodic_kernel, ref_rbf_kernel
 
 rng = np.random.RandomState(1)
@@ -670,3 +671,78 @@ def test_combination_LMC_kernels() -> None:
     K = kernel(X, full_cov=True)
     assert K.shape == [N, P, N, P]
     np.testing.assert_allclose(K, K1 + K2)
+
+
+def test_concat_inputs_with_latents() -> None:
+    X = tf.constant(
+        [
+            [0.11333948, 0.0],
+            [0.68914756, 0.0],
+            [0.49686943, 0.0],
+            [0.93093605, 0.0],
+            [0.49400229, 0.0],
+            [0.2563728, 0.0],
+            [0.60688866, 0.0],
+            [0.26627661, 0.0],
+            [0.17639742, 0.0],
+            [0.12579375, 0.0],
+            [0.94793767, 1.0],
+            [0.57164863, 1.0],
+            [0.05673398, 1.0],
+            [0.27555594, 1.0],
+            [0.89225699, 1.0],
+            [0.73987146, 1.0],
+            [0.06209851, 1.0],
+            [0.91578623, 1.0],
+            [0.38951871, 1.0],
+            [0.25707253, 1.0],
+            [0.92527423, 2.0],
+            [0.12519213, 2.0],
+            [0.27104576, 2.0],
+            [0.24123346, 2.0],
+            [0.77848324, 2.0],
+            [0.45188542, 2.0],
+            [0.12848926, 2.0],
+            [0.67861482, 2.0],
+            [0.43295772, 2.0],
+            [0.26668177, 2.0],
+        ],
+        dtype=tf.float64,
+    )
+    Z = tf.constant([[0.0], [0.5], [1.0]], dtype=tf.float64)
+    result = tf.constant(
+        [
+            [0.11333948, 0.0],
+            [0.68914756, 0.0],
+            [0.49686943, 0.0],
+            [0.93093605, 0.0],
+            [0.49400229, 0.0],
+            [0.2563728, 0.0],
+            [0.60688866, 0.0],
+            [0.26627661, 0.0],
+            [0.17639742, 0.0],
+            [0.12579375, 0.0],
+            [0.94793767, 0.5],
+            [0.57164863, 0.5],
+            [0.05673398, 0.5],
+            [0.27555594, 0.5],
+            [0.89225699, 0.5],
+            [0.73987146, 0.5],
+            [0.06209851, 0.5],
+            [0.91578623, 0.5],
+            [0.38951871, 0.5],
+            [0.25707253, 0.5],
+            [0.92527423, 1.0],
+            [0.12519213, 1.0],
+            [0.27104576, 1.0],
+            [0.24123346, 1.0],
+            [0.77848324, 1.0],
+            [0.45188542, 1.0],
+            [0.12848926, 1.0],
+            [0.67861482, 1.0],
+            [0.43295772, 1.0],
+            [0.26668177, 1.0],
+        ],
+        dtype=tf.float64,
+    )
+    assert np.all(_concat_inputs_with_latents(Z, X) == result)
