@@ -12,11 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import unittest
 import warnings
+from typing import Any, Dict
+from unittest.mock import MagicMock
 
 import numpy as np
 import pytest
 import tensorflow as tf
+from packaging.version import Version
 
 import gpflow
 from gpflow.base import AnyNDArray
@@ -25,6 +29,11 @@ from gpflow.models import GPR, GPModel
 
 rng = np.random.RandomState(0)
 
+if Version(tf.__version__) >= Version("2.5"):
+    jit_compile_arg = "jit_compile"
+else:
+    jit_compile_arg = "experimental_compile"
+
 
 class Datum:
     X: AnyNDArray = rng.rand(20, 1) * 10
@@ -48,9 +57,11 @@ def _create_full_gp_model() -> GPModel:
 def test_scipy_jit() -> None:
     m1 = _create_full_gp_model()
     m2 = _create_full_gp_model()
+    m3 = _create_full_gp_model()
 
     opt1 = gpflow.optimizers.Scipy()
     opt2 = gpflow.optimizers.Scipy()
+    opt3 = gpflow.optimizers.Scipy()
 
     opt1.minimize(
         m1.training_loss,
@@ -64,15 +75,59 @@ def test_scipy_jit() -> None:
         options=dict(maxiter=50),
         compile=True,
     )
+    opt3.minimize(
+        m3.training_loss,
+        variables=m3.trainable_variables,
+        options=dict(maxiter=50),
+        compile=True,
+        tf_fun_args={jit_compile_arg: True},
+    )
 
     def get_values(model: GPModel) -> AnyNDArray:
         return np.array([var.numpy().squeeze() for var in model.trainable_variables])
 
     np.testing.assert_allclose(get_values(m1), get_values(m2), rtol=1e-13, atol=1e-13)
+    np.testing.assert_allclose(get_values(m1), get_values(m3), rtol=1e-13, atol=1e-13)
 
 
+@unittest.mock.patch("tensorflow.function")
 @pytest.mark.parametrize("compile", [True, False])
-def test_scipy__optimal(compile: bool) -> None:
+@pytest.mark.parametrize(
+    "tf_fun_args",
+    [{}, dict(jit_compile=True), dict(jit_compile=False, other_arg="dummy")],
+)
+def test_scipy__tf_fun_args(
+    mocked_tf_fun: MagicMock, compile: bool, tf_fun_args: Dict[str, Any]
+) -> None:
+    mocked_tf_fun.side_effect = lambda f, **_: f
+
+    m = _create_full_gp_model()
+    opt = gpflow.optimizers.Scipy()
+    expect_raise = not compile and len(tf_fun_args)
+    if expect_raise:
+        with pytest.raises(
+            ValueError, match="`tf_fun_args` should only be set when `compile` is True"
+        ):
+            opt.minimize(
+                m.training_loss, m.trainable_variables, compile=compile, tf_fun_args=tf_fun_args
+            )
+    else:
+        opt.minimize(
+            m.training_loss, m.trainable_variables, compile=compile, tf_fun_args=tf_fun_args
+        )
+
+    if compile:
+        received_args = mocked_tf_fun.call_args[1]
+        expected_args = tf_fun_args
+    else:
+        # When no-compile, don't expect tf.function to be called.
+        received_args = mocked_tf_fun.call_args
+        expected_args = None
+    assert received_args == expected_args
+
+
+@pytest.mark.parametrize("compile,jit", [(True, True), (True, False), (False, False)])
+def test_scipy__optimal(compile: bool, jit: bool) -> None:
     target1 = [0.2, 0.8]
     target2 = [0.6]
     v1 = tf.Variable([0.5, 0.5], dtype=default_float())
@@ -85,7 +140,8 @@ def test_scipy__optimal(compile: bool) -> None:
         return tf.reduce_sum((target1 - v1) ** 2) + tf.reduce_sum((target2 - v2) ** 2)
 
     opt = gpflow.optimizers.Scipy()
-    result = opt.minimize(f, [v1, v2], compile=compile)
+    tf_fun_args = {jit_compile_arg: True} if jit else {}
+    result = opt.minimize(f, [v1, v2], compile=compile, tf_fun_args=tf_fun_args)
 
     if compile:
         assert 1 == compilation_count
@@ -97,8 +153,8 @@ def test_scipy__optimal(compile: bool) -> None:
     np.testing.assert_allclose(target2, v2)
 
 
-@pytest.mark.parametrize("compile", [True, False])
-def test_scipy__partially_disconnected_variable(compile: bool) -> None:
+@pytest.mark.parametrize("compile,jit", [(True, True), (True, False), (False, False)])
+def test_scipy__partially_disconnected_variable(compile: bool, jit: bool) -> None:
     target1 = 0.2
     target2 = 0.6
     v1 = tf.Variable([0.5, 0.5], dtype=default_float())
@@ -110,7 +166,8 @@ def test_scipy__partially_disconnected_variable(compile: bool) -> None:
         return (target1 - v10) ** 2 + (target2 - v2) ** 2
 
     opt = gpflow.optimizers.Scipy()
-    result = opt.minimize(f, [v1, v2], compile=compile)
+    tf_fun_args = {jit_compile_arg: True} if jit else {}
+    result = opt.minimize(f, [v1, v2], compile=compile, tf_fun_args=tf_fun_args)
 
     assert result.success
     np.testing.assert_allclose([target1, 0.5, target2], result.x)
@@ -118,9 +175,11 @@ def test_scipy__partially_disconnected_variable(compile: bool) -> None:
     np.testing.assert_allclose(target2, v2)
 
 
-@pytest.mark.parametrize("compile", [True, False])
+@pytest.mark.parametrize("compile,jit", [(True, True), (True, False), (False, False)])
 @pytest.mark.parametrize("allow_unused_variables", [True, False])
-def test_scipy__disconnected_variable(compile: bool, allow_unused_variables: bool) -> None:
+def test_scipy__disconnected_variable(
+    compile: bool, jit: bool, allow_unused_variables: bool
+) -> None:
     target1 = [0.2, 0.8]
     v1 = tf.Variable([0.5, 0.5], dtype=default_float(), name="v1")
     v2 = tf.Variable([0.5], dtype=default_float(), name="v2")
@@ -130,12 +189,17 @@ def test_scipy__disconnected_variable(compile: bool, allow_unused_variables: boo
         return tf.reduce_sum((target1 - v1) ** 2)
 
     opt = gpflow.optimizers.Scipy()
+    tf_fun_args = {jit_compile_arg: True} if jit else {}
 
     if allow_unused_variables:
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always")
             result = opt.minimize(
-                f, [v1, v2], compile=compile, allow_unused_variables=allow_unused_variables
+                f,
+                [v1, v2],
+                compile=compile,
+                allow_unused_variables=allow_unused_variables,
+                tf_fun_args=tf_fun_args,
             )
 
         (warning,) = w
@@ -150,4 +214,10 @@ def test_scipy__disconnected_variable(compile: bool, allow_unused_variables: boo
         np.testing.assert_allclose([0.5], v2)
     else:
         with pytest.raises(ValueError, match=v2.name):
-            opt.minimize(f, [v1, v2], allow_unused_variables=allow_unused_variables)
+            opt.minimize(
+                f,
+                [v1, v2],
+                compile=compile,
+                allow_unused_variables=allow_unused_variables,
+                tf_fun_args=tf_fun_args,
+            )
